-- Examine pages and records
-- Introducing DBCC PAGE and DBCC IND
-- Connections April 2008

USE ConnectionsApril2008;
GO

-- Create a test table to use
CREATE TABLE DbccPageTest (
	intCol1	INT IDENTITY,
	intCol2	INT,
	charCol	VARCHAR (8000),
	lobCol	VARCHAR (MAX));

INSERT INTO DbccPageTest VALUES (
	1, REPLICATE ('Paul', 600), REPLICATE ('a', 8000));
INSERT INTO DbccPageTest VALUES (
	2, REPLICATE ('Kimberly', 275), REPLICATE ('b', 8000));
INSERT INTO DbccPageTest VALUES (
	3, REPLICATE ('Kiera', 440), REPLICATE ('c', 8000));
INSERT INTO DbccPageTest VALUES (
	4, REPLICATE ('Katelyn', 340), REPLICATE ('d', 8000));
GO

-- Introducing sp_allocationMetadata
EXEC sp_AllocationMetadata 'DbccPageTest';
GO

-- Pick a data page and use DBCC PAGE on
-- it. We just happen to know that the
-- first page is the first listed.
-- Trace flag is required to make output
-- go to the console rather than the
-- errorlog.
-- Takes db, file, page, print option 1-3
DBCC TRACEON (3604);
GO

-- Option 1 is a hex dump of each record
-- plus interpreting the slot array.
DBCC PAGE ('ConnectionsApril2008', 1, 153, 1);
GO

-- Data page with data records

-- Option 2 is a hex dump of the page plus
-- interpreting the slot array
DBCC PAGE ('ConnectionsApril2008', 1, XX, 2);
GO

-- Option 3 interprets each record fully
DBCC PAGE ('ConnectionsApril2008', 1, 153, 3);
GO

-- Note the off-row link. Let's follow it.
DBCC PAGE ('ConnectionsApril2008', 1, 155, 3);
GO

-- Text page

-- New we create a clustered index
CREATE CLUSTERED INDEX DbccCL
	ON DbccPageTest (intCol1);
GO

-- And look at the pages again
EXEC sp_AllocationMetadata 'DbccPageTest';
GO

-- Look at the root page
DBCC PAGE ('ConnectionsApril2008', 1, 163, 1);
GO

-- Index page with index records
-- Let's take a closer look.
DBCC PAGE ('ConnectionsApril2008', 1, 163, 3);
GO

-- Explain the various columns