-- Script to demonstrate the effect of data file shrink
-- Connections April 2008

USE MASTER;
GO

IF DATABASEPROPERTYEX ('shrinktest', 'Version') > 0
	DROP DATABASE shrinktest;

CREATE DATABASE shrinktest;
GO
USE shrinktest;
GO

SET NOCOUNT ON;
GO

-- Create the 10MB filler table
CREATE TABLE filler (c1 INT IDENTITY, c2 VARCHAR(8000))
GO

-- Fill up the filler table
DECLARE @a INT;
SELECT @a = 1;
WHILE (@a < 1280) -- insert 10MB
BEGIN
	INSERT INTO filler VALUES (
		REPLICATE ('a', 5000));
	SELECT @a = @a + 1;
END;
GO

-- Create the production table
CREATE TABLE production (
	c1 INT IDENTITY, c2 VARCHAR (8000));
CREATE CLUSTERED INDEX prod_cl ON production (c1);
GO
DECLARE @a INT;
SELECT @a = 1;
WHILE (@a < 1280) -- insert 10MB
BEGIN
	INSERT INTO production VALUES (
		REPLICATE ('a', 5000));
	SELECT @a = @a + 1;
END;
GO

-- check the fragmentation of the production table
SELECT avg_fragmentation_in_percent, fragment_count
	FROM sys.dm_db_index_physical_stats (
		DB_ID ('shrinktest'), OBJECT_ID ('production'),
		1, NULL, 'LIMITED');
GO

-- drop the filler table and shrink the database
DROP TABLE filler;
GO

-- shrink the database
DBCC SHRINKDATABASE (shrinktest);
GO

-- check the index fragmentation again
SELECT avg_fragmentation_in_percent, fragment_count FROM
	sys.dm_db_index_physical_stats (
		DB_ID ('shrinktest'), OBJECT_ID ('production'),
		1, NULL, 'LIMITED');
GO